@@ -46,31 +46,32 @@ typedef struct {
 struct hdfs_library {
 	void *libjvm_handle;
 	void *libhdfs_handle;
-	  hdfsFS(*connect) (const char *, tPort);
-	  hdfsFS(*connect_as_user) (const char *, tPort, const char *, const char *[], int);
+	hdfsFS (*connect) (const char *, tPort);
+	hdfsFS (*connect_as_user) (const char *, tPort, const char *, const char *[], int);
 	int (*disconnect) (hdfsFS);
 	hdfsFileInfo *(*listdir) (hdfsFS, const char *, int *);
-	  hdfsFile(*open) (hdfsFS, const char *, int, int, short, tSize);
+	hdfsFile (*open) (hdfsFS, const char *, int, int, short, tSize);
 	int (*close) (hdfsFS, hdfsFile);
 	int (*flush) (hdfsFS, hdfsFile);
-	  tSize(*read) (hdfsFS, hdfsFile, void *, tSize);
-	  tSize(*pread) (hdfsFS, hdfsFile, tOffset, void *, tSize);
-	  tSize(*write) (hdfsFS, hdfsFile, const void *, tSize);
+	tSize (*read) (hdfsFS, hdfsFile, void *, tSize);
+	tSize (*pread) (hdfsFS, hdfsFile, tOffset, void *, tSize);
+	tSize (*write) (hdfsFS, hdfsFile, const void *, tSize);
 	int (*exists) (hdfsFS, const char *);
 	int (*mkdir) (hdfsFS, const char *);
-	int (*unlink) (hdfsFS, const char *);
+	int (*unlink) (hdfsFS, const char *, int recursive);
 	int (*rename) (hdfsFS, const char *, const char *);
 	hdfsFileInfo *(*stat) (hdfsFS, const char *);
 	void (*free_stat) (hdfsFileInfo *, int);
 	char ***(*get_hosts) (hdfsFS, const char *, tOffset, tOffset);
 	void (*free_hosts) (char ***);
-	  tOffset(*get_default_block_size) (hdfsFS);
-	  tOffset(*get_capacity) (hdfsFS);
-	  tOffset(*get_used) (hdfsFS);
+	tOffset (*get_default_block_size) (hdfsFS);
+	tOffset (*get_capacity) (hdfsFS);
+	tOffset (*get_used) (hdfsFS);
 	int (*chmod) (hdfsFS, const char *, short);
 	int (*utime) (hdfsFS, const char *, tTime, tTime);
 	int (*chdir) (hdfsFS, const char *);
-	  tOffset(*tell) (hdfsFS, hdfsFile);
+	tOffset (*tell) (hdfsFS, hdfsFile);
+	int (*setrep) (hdfsFS fs, const char *path, UINT16_T nreps );
 };
 
 struct hdfs_library *hdfs_library_open();
