@@ -12,6 +12,7 @@ See the file COPYING for details.
 
 typedef char *(*string_subst_lookup_t) (const char *name, void *arg);
 
+char *escape_shell_string (const char *str);
 void string_from_ip_address(const unsigned char *ip_addr_bytes, char *str);
 int string_to_ip_address(const char *str, unsigned char *ip_addr_bytes);
 int string_ip_subnet(const char *addr, char *subnet);
@@ -49,6 +50,18 @@ int strrpos(const char *str, char c);
 int getDateString(char *str);
 int string_null_or_empty(const char *str);
 
+/** Returns a heap allocated freeable string formatted using sprintf.
+    @param fmt Format string passed to sprintf.
+	@param ... Variable arguments passed to sprintf.
+	@return The formatted string.
+ */
+char *string_format (const char *fmt, ...);
+
+/** Returns a heap allocated freeable string for the current working directory.
+	@return The current working directory.
+ */
+char *string_getcwd (void);
+
 #ifndef CCTOOLS_OPSYS_LINUX
 char *strsep(char **stringp, const char *delim);
 #endif
